pyxmpp2.interfaces.StreamFeatureHandled

Package pyxmpp2 :: Module interfaces :: Class StreamFeatureHandled |
[hide private]

# Class StreamFeatureHandled

Object returned by a stream feature handler for recognized and handled features.

Instance Methods | [hide private]
__init__(self, feature_name, mandatory=False) x.__init__(...) initializes x; see help(type(x)) for signature |
__repr__(self) repr(x) |
__str__(self) str(x) |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, feature_name, mandatory=False) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)